%define rel 1
%define grantlee_major 5
%define grantlee_minor 3

Name:           grantlee
Summary:        Qt string template engine based on the Django template system
Group:          System/Libraries
Version:        %{grantlee_major}.%{grantlee_minor}.1
Release:        %mkrel %{rel}
License:        LGPLv2+
URL:            https://github.com/steveire/grantlee
Source0:        https://github.com/steveire/grantlee/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  lcov

BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Script)

%description
Grantlee is a plugin based String Template system written using the Qt framework.
The goals of the project are to make it easier for application developers to
separate the structure of documents from the data they contain, opening the door
for theming.

The syntax is intended to follow the syntax of the Django template system, and
the design of Django is reused in Grantlee. Django is covered by a BSD style license.

Part of the design of both is that application developers can extend the syntax by
implementing their own tags and filters. For details of how to do that, see the API
documentation.

For template authors, different applications using Grantlee will present the same
interface and core syntax for creating new themes. For details of how to write
templates, see the documentation.

%files
%doc AUTHORS CHANGELOG README.md
%license COPYING.LIB
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{grantlee_major}.%{grantlee_minor}
%{_libdir}/%{name}/%{grantlee_major}.%{grantlee_minor}/*

#--------------------------------------------------------------------

%define libgrantlee_template %mklibname grantlee_template %{grantlee_major}

%package -n %libgrantlee_template
Summary:        Library files for %{name}
Group:          System/Libraries

%description  -n %libgrantlee_template
Libraries for %{name}.

%files -n %libgrantlee_template
%license COPYING.LIB
%{_libdir}/libGrantlee_Templates.so.%{grantlee_major}.%{grantlee_minor}{,.*}
%{_libdir}/libGrantlee_Templates.so.%{grantlee_major}

#--------------------------------------------------------------------

%define libgrantlee_textdocument %mklibname grantlee_textdocument %{grantlee_major}

%package -n %libgrantlee_textdocument
Summary:    Library files for %{name}
Group:      System/Libraries

%description  -n %libgrantlee_textdocument
Libraries for %{name}.

%files -n %libgrantlee_textdocument
%license COPYING.LIB
%{_libdir}/libGrantlee_TextDocument.so.%{grantlee_major}.%{grantlee_minor}{,.*}
%{_libdir}/libGrantlee_TextDocument.so.%{grantlee_major}

#--------------------------------------------------------------------

%define devname %mklibname %{name} -d

%package -n %{devname}
Summary:       Development files for %{name}
Group:         Development/KDE and Qt
Requires:      %name = %{version}-%{release}
Requires:      %libgrantlee_template = %{version}-%{release}
Requires:      %libgrantlee_textdocument = %{version}-%{release}
Provides:      %{name}-devel = %{version}-%{release}

%description -n %{devname}
Libraries and header files to develop applications that use %{name}.

%files -n %{devname}
%doc AUTHORS CHANGELOG README.md
%{_includedir}/%{name}/
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/cmake/Grantlee5

#--------------------------------------------------------------------

%prep
%setup -q

%build
%cmake_qt5
%cmake_build

%install
%cmake_install


%changelog
* Wed Apr 19 2023 daviddavid <daviddavid> 5.3.1-1.mga9
+ Revision: 1953631
- new version: 5.3.1

* Mon Apr 04 2022 umeabot <umeabot> 5.2.0-2.mga9
+ Revision: 1843109
- Mageia 9 Mass Rebuild

* Mon Feb 17 2020 daviddavid <daviddavid> 5.2.0-1.mga8
+ Revision: 1536970
- new version: 5.2.0
- fix devel pkg name

* Sat Feb 15 2020 umeabot <umeabot> 5.1.0-5.mga8
+ Revision: 1528463
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Wed Aug 21 2019 daviddavid <daviddavid> 5.1.0-4.mga8
+ Revision: 1430717
- update to latest git snapshot: 5.1.0-git20190815

* Sat Mar 30 2019 umeabot <umeabot> 5.1.0-3.mga7
+ Revision: 1381856
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 5.1.0-2.mga7
+ Revision: 1298062
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Use new make macros

* Wed May 11 2016 luigiwalser <luigiwalser> 5.1.0-1.mga6
+ Revision: 1013226
- 5.1.0

* Mon Feb 15 2016 umeabot <umeabot> 5.0.0-10.mga6
+ Revision: 960541
- Mageia 6 Mass Rebuild

* Wed Jul 22 2015 neoclust <neoclust> 5.0.0-9.mga6
+ Revision: 856084
- Fix Requires

* Wed Jul 22 2015 neoclust <neoclust> 5.0.0-8.mga6
+ Revision: 856073
- Fix packages name

* Wed Jul 22 2015 neoclust <neoclust> 5.0.0-7.mga6
+ Revision: 856067
- New version 5.0.0

* Wed Oct 15 2014 umeabot <umeabot> 0.4.0-7.mga5
+ Revision: 750073
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.4.0-6.mga5
+ Revision: 679928
- Mageia 5 Mass Rebuild

* Sun Dec 22 2013 lmenut <lmenut> 0.4.0-5.mga4
+ Revision: 559745
- fix libification

* Fri Dec 06 2013 neoclust <neoclust> 0.4.0-4.mga4
+ Revision: 555538
- New version 0.4.0

* Sat Oct 19 2013 umeabot <umeabot> 0.3.0-4.mga4
+ Revision: 523649
- Mageia 4 Mass Rebuild
+ fwang <fwang>
- drop dup provides

* Thu May 23 2013 fwang <fwang> 0.3.0-3.mga4
+ Revision: 425631
- fix provides

* Sat Jan 12 2013 umeabot <umeabot> 0.3.0-2.mga3
+ Revision: 352564
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 03 2013 mikala <mikala> 0.3.0-1.mga3
+ Revision: 337912
- Update tarball to 0.3.0
- Use minor in libname package (same stuff as attica)
- Use pkgconfig() for BR

* Sun Aug 19 2012 neoclust <neoclust> 0.2.0-1.mga3
+ Revision: 282263
- Update tarball to final 2.0.0
- Drop patch (merged upstream)

* Mon Jan 23 2012 dmorgan <dmorgan> 0.2.0-0.rc1.4.mga2
+ Revision: 200206
- Fix package ownage

* Fri Oct 07 2011 fwang <fwang> 0.2.0-0.rc1.3.mga2
+ Revision: 152686
- add upstream patch to fix parsearguments install

* Fri Oct 07 2011 fwang <fwang> 0.2.0-0.rc1.2.mga2
+ Revision: 152667
- install extra cmake file

* Mon Sep 26 2011 mikala <mikala> 0.2.0-0.rc1.1.mga2
+ Revision: 147890
- Update tarball to 0.2 rc1
- remove %%defattr(),%%clean section

* Sat Jun 25 2011 mikala <mikala> 0.1.9-2.mga2
+ Revision: 113371
- Fix various rpmlint warning (group for grantlee-devel, use of spaces)

* Fri Jun 24 2011 mikala <mikala> 0.1.9-1.mga2
+ Revision: 113256
- Update tarball to 1.9
- imported package grantlee
+ dmorgan <dmorgan>
- Revert commit  100824 because :
 1- You need to see with the package maintainer first
 2- This is still cauldront svn tree for Mageia 1
+ ze <ze>
- version 0.1.8
- dont use kde4 macros since doesnt buildrequire kde4
- use qt4 macros since its a qt framework and also fix package groups naming
- move develop files to devel package
- no need to use -n flag in %%setup macro since name-version its used by default
- list dirs so that can be removed in package uninstall


* Tue Aug 03 2010 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.1.4-1mdv2011.0
+ Revision: 565191
- Fix groups
- Add Buildrequires
- Fix groups
- New version 0.1.4
  Adapt Spec file to kde policy
- start to clean the spec file ( next step => clean lib package)

  + José Melo <mmodem@mandriva.org>
    - add needed changes to for a correct packaging policy (library files in a lib packge) and fix the apidox variable name and enable it to build since its tested.
    - import grantlee


* Tue Jun 29 2010 Zé <ze@mandriva.org> 0.1.1-1
- first release
